View Source ExTDLib.Method.AnswerCallbackQuery (ExTDLib v0.0.4)

Sets the result of a callback query; for bots only. Returns object_ptr<Ok>.

NameTypeDescription
callback_query_idstringIdentifier of the callback query.
textstringText of the answer.
show_alertboolPass true to show an alert to the user instead of a toast notification.
urlstringURL to be opened.
cache_timenumberTime during which the result of the query can be cached, in seconds.

More details on telegram's documentation.