View Source ExTDLib.Method.CloseChat (ExTDLib v0.0.4)

Informs TDLib that the chat is closed by the user. Many useful activities depend on the chat being opened or closed. Returns object_ptr<Ok>.

NameTypeDescription
chat_idstringChat identifier.

More details on telegram's documentation.