View Source ExTDLib.Method.CreateNewStickerSet (ExTDLib v0.0.4)

Creates a new sticker set. Returns the newly created sticker set. Returns object_ptr<StickerSet>.

NameTypeDescription
user_idstringSticker set owner; ignored for regular users.
titlestringSticker set title; 1-64 characters.
namestringSticker set name. Can contain only English letters, digits and underscores. Must end with "by<bot username>" (<bot_username> is case insensitive) for bots; 1-64 characters.
sticker_formatStickerFormatFormat of the stickers in the set.
sticker_typeStickerTypeType of the stickers in the set.
needs_repaintingboolPass true if stickers in the sticker set must be repainted; for custom emoji sticker sets only.
stickersinputStickerList of stickers to be added to the set; must be non-empty. All stickers must have the same format. For TGS stickers, uploadStickerFile must be used before the sticker is shown.
sourcestringSource of the sticker set; may be empty if unknown.

More details on telegram's documentation.