View Source ExTDLib.Method.GetEmojiSuggestionsUrl (ExTDLib v0.0.4)
Returns an HTTP URL which can be used to automatically log in to the translation platform and suggest new emoji replacements. The URL will be valid for 30 seconds after generation. Returns object_ptr<HttpUrl>.
| Name | Type | Description |
|---|---|---|
| language_code | string | Language code for which the emoji replacements will be suggested. |
More details on telegram's documentation.