View Source ExTDLib.Method.GetStoryPublicForwards (ExTDLib v0.0.4)
Returns forwards of a story as a message to public chats and reposts by public channels. Can be used only if the story is posted on behalf of the current user or story.can_get_statistics == true. For optimal performance, the number of returned messages and stories is chosen by TDLib. Returns object_ptr<StoryPublicForwards>.
| Name | Type | Description |
|---|---|---|
| story_sender_chat_id | string | The identifier of the sender of the story. |
| story_id | number | The identifier of the story. |
| offset | string | Offset of the first entry to return as received from the previous request; use empty string to get the first chunk of results. |
| limit | number | The maximum number of messages and stories to be returned; must be positive and can't be greater than 100. For optimal performance, the number of returned objects is chosen by TDLib and can be smaller than the specified limit. |
More details on telegram's documentation.