View Source ExTDLib.Method.JoinGroupCall (ExTDLib v0.0.4)

Joins an active group call. Returns join response payload for tgcalls. Returns object_ptr<Text>.

NameTypeDescription
group_call_idnumberGroup call identifier.
participant_idMessageSenderIdentifier of a group call participant, which will be used to join the call; pass null to join as self; video chats only.
audio_source_idnumberCaller audio channel synchronization source identifier; received from tgcalls.
payloadstringGroup call join payload; received from tgcalls.
is_mutedboolPass true to join the call with muted microphone.
is_my_video_enabledboolPass true if the user's video is enabled.
invite_hashstringIf non-empty, invite hash to be used to join the group call without being muted by administrators.

More details on telegram's documentation.