View Source ExTDLib.Method.SearchMessages (ExTDLib v0.0.4)

Searches for messages in all chats except secret chats. Returns the results in reverse chronological order (i.e., in order of decreasing (date, chat_id, message_id)). For optimal performance, the number of returned messages is chosen by TDLib and can be smaller than the specified limit. Returns object_ptr<FoundMessages>.

NameTypeDescription
chat_listChatListChat list in which to search messages; pass null to search in all chats regardless of their chat list. Only Main and Archive chat lists are supported.
querystringQuery to search for.
offsetstringOffset of the first entry to return as received from the previous request; use empty string to get the first chunk of results.
limitnumberThe maximum number of messages to be returned; up to 100. For optimal performance, the number of returned messages is chosen by TDLib and can be smaller than the specified limit.
filterSearchMessagesFilterAdditional filter for messages to search; pass null to search for all messages. Filters searchMessagesFilterMention, searchMessagesFilterUnreadMention, searchMessagesFilterUnreadReaction, searchMessagesFilterFailedToSend, and searchMessagesFilterPinned are unsupported in this function.
min_datenumberIf not 0, the minimum date of the messages to return.
max_datenumberIf not 0, the maximum date of the messages to return.

More details on telegram's documentation.