View Source ExTDLib.Method.ShareUserWithBot (ExTDLib v0.0.4)

Shares a user after pressing a keyboardButtonTypeRequestUser button with the bot. Returns object_ptr<Ok>.

NameTypeDescription
chat_idstringIdentifier of the chat with the bot.
message_idstringIdentifier of the message with the button.
button_idnumberIdentifier of the button.
shared_user_idstringIdentifier of the shared user.
only_checkboolPass true to check that the user can be shared by the button instead of actually sharing them.

More details on telegram's documentation.