View Source ExTDLib.Object.AuthenticationCodeTypeFlashCall (ExTDLib v0.0.4)
An authentication code is delivered by an immediately canceled call to the specified phone number. The phone number that calls is the code that must be entered automatically.
| Name | Type | Description |
|---|---|---|
| pattern | string | Pattern of the phone number from which the call will be made. |
More details on telegram's documentation.