View Source ExTDLib.Object.CanSendStoryResultPremiumNeeded (ExTDLib v0.0.4)
The user must subscribe to Telegram Premium to be able to post stories.
More details on telegram's documentation.
The user must subscribe to Telegram Premium to be able to post stories.
More details on telegram's documentation.