View Source ExTDLib.Object.ChatMember (ExTDLib v0.0.4)

Describes a user or a chat as a member of another chat.

NameTypeDescription
member_idMessageSenderIdentifier of the chat member. Currently, other chats can be only Left or Banned. Only supergroups and channels can have other chats as Left or Banned members and these chats must be supergroups or channels.
inviter_user_idstringIdentifier of a user that invited/promoted/banned this member in the chat; 0 if unknown.
joined_chat_datenumberPoint in time (Unix timestamp) when the user joined/was promoted/was banned in the chat.
statusChatMemberStatusStatus of the member in the chat.

More details on telegram's documentation.