View Source ExTDLib.Object.ChatMemberStatusRestricted (ExTDLib v0.0.4)

The user is under certain restrictions in the chat. Not supported in basic groups and channels.

NameTypeDescription
is_memberboolTrue, if the user is a member of the chat.
restricted_until_datenumberPoint in time (Unix timestamp) when restrictions will be lifted from the user; 0 if never. If the user is restricted for more than 366 days or for less than 30 seconds from the current time, the user is considered to be restricted forever.
permissionschatPermissionsUser permissions in the chat.

More details on telegram's documentation.