View Source ExTDLib.Object.ChatMembersFilterBanned (ExTDLib v0.0.4)
Returns users banned from the chat; can be used only by administrators in a supergroup or in a channel.
More details on telegram's documentation.
Returns users banned from the chat; can be used only by administrators in a supergroup or in a channel.
More details on telegram's documentation.