View Source ExTDLib.Object.CheckChatUsernameResultPublicChatsTooMany (ExTDLib v0.0.4)
The user has too many chats with username, one of them must be made private first.
More details on telegram's documentation.
The user has too many chats with username, one of them must be made private first.
More details on telegram's documentation.