View Source ExTDLib.Object.EmojiCategory (ExTDLib v0.0.4)

Contains a list of similar emoji to search for in getStickers and searchStickers.

NameTypeDescription
namestringName of the category.
iconstickerCustom emoji sticker, which represents icon of the category.
emojisstringList of emojis in the category.

More details on telegram's documentation.