View Source ExTDLib.Object.InputStoryAreas (ExTDLib v0.0.4)
Contains a list of story areas to be added.
| Name | Type | Description |
|---|---|---|
| areas | inputStoryArea | List of 0-10 input story areas. |
More details on telegram's documentation.
Contains a list of story areas to be added.
| Name | Type | Description |
|---|---|---|
| areas | inputStoryArea | List of 0-10 input story areas. |
More details on telegram's documentation.