View Source ExTDLib.Object.LoginUrlInfoRequestConfirmation (ExTDLib v0.0.4)

An authorization confirmation dialog needs to be shown to the user.

NameTypeDescription
urlstringAn HTTP URL to be opened.
domainstringA domain of the URL.
bot_user_idstringUser identifier of a bot linked with the website.
request_write_accessboolTrue, if the user must be asked for the permission to the bot to send them messages.

More details on telegram's documentation.