View Source ExTDLib.Object.MessageSponsorTypePublicChannel (ExTDLib v0.0.4)

The sponsor is a public channel chat.

NameTypeDescription
chat_idstringSponsor chat identifier.
linkInternalLinkTypeAn internal link to be opened when the sponsored message is clicked; may be null if the sponsor chat needs to be opened instead.

More details on telegram's documentation.