View Source ExTDLib.Object.PassportElementErrorSourceReverseSide (ExTDLib v0.0.4)
The reverse side of the document contains an error. The error will be considered resolved when the file with the reverse side changes.
More details on telegram's documentation.