View Source ExTDLib.Object.PassportSuitableElement (ExTDLib v0.0.4)

Contains information about a Telegram Passport element that was requested by a service.

NameTypeDescription
typePassportElementTypeType of the element.
is_selfie_requiredboolTrue, if a selfie is required with the identity document.
is_translation_requiredboolTrue, if a certified English translation is required with the document.
is_native_name_requiredboolTrue, if personal details must include the user's name in the language of their country of residence.

More details on telegram's documentation.