View Source ExTDLib.Object.PaymentProviderOther (ExTDLib v0.0.4)
Some other payment provider, for which a web payment form must be shown.
| Name | Type | Description |
|---|---|---|
| url | string | Payment form URL. |
More details on telegram's documentation.
Some other payment provider, for which a web payment form must be shown.
| Name | Type | Description |
|---|---|---|
| url | string | Payment form URL. |
More details on telegram's documentation.