View Source ExTDLib.Object.PremiumFeatureCustomEmoji (ExTDLib v0.0.4)
Allowed to use custom emoji stickers in message texts and captions.
More details on telegram's documentation.
Allowed to use custom emoji stickers in message texts and captions.
More details on telegram's documentation.