View Source ExTDLib.Object.PremiumGiveawayInfoCompleted (ExTDLib v0.0.4)

Describes a completed giveaway.

NameTypeDescription
creation_datenumberPoint in time (Unix timestamp) when the giveaway was created.
actual_winners_selection_datenumberPoint in time (Unix timestamp) when the winners were selected. May be bigger than winners selection date specified in parameters of the giveaway.
was_refundedboolTrue, if the giveaway was canceled and was fully refunded.
winner_countnumberNumber of winners in the giveaway.
activation_countnumberNumber of winners, which activated their gift codes.
gift_codestringTelegram Premium gift code that was received by the current user; empty if the user isn't a winner in the giveaway.

More details on telegram's documentation.