View Source ExTDLib.Object.PremiumGiveawayParticipantStatusAdministrator (ExTDLib v0.0.4)

The user can't participate in the giveaway, because they are an administrator in one of the chats that created the giveaway.

NameTypeDescription
chat_idstringIdentifier of the chat administered by the user.

More details on telegram's documentation.