View Source ExTDLib.Object.PremiumLimitTypeChatFolderChosenChatCount (ExTDLib v0.0.4)
The maximum number of pinned and always included, or always excluded chats in a chat folder.
More details on telegram's documentation.
The maximum number of pinned and always included, or always excluded chats in a chat folder.
More details on telegram's documentation.