View Source ExTDLib.Object.PremiumLimitTypeStorySuggestedReactionAreaCount (ExTDLib v0.0.4)
The maximum number of suggested reaction areas on a story.
More details on telegram's documentation.
The maximum number of suggested reaction areas on a story.
More details on telegram's documentation.