View Source ExTDLib.Object.PremiumState (ExTDLib v0.0.4)

Contains state of Telegram Premium subscription and promotion videos for Premium features.

NameTypeDescription
stateformattedTextText description of the state of the current Premium subscription; may be empty if the current user has no Telegram Premium subscription.
payment_optionspremiumStatePaymentOptionThe list of available options for buying Telegram Premium.
animationspremiumFeaturePromotionAnimationThe list of available promotion animations for Premium features.

More details on telegram's documentation.