View Source ExTDLib.Object.PremiumStoryFeatureStealthMode (ExTDLib v0.0.4)
The ability to hide the fact that the user viewed other's stories.
More details on telegram's documentation.
The ability to hide the fact that the user viewed other's stories.
More details on telegram's documentation.