View Source ExTDLib.Object.PrepaidPremiumGiveaway (ExTDLib v0.0.4)

Describes a prepaid Telegram Premium giveaway.

NameTypeDescription
idstringUnique identifier of the prepaid giveaway.
winner_countnumberNumber of users which will receive Telegram Premium subscription gift codes.
month_countnumberNumber of month the Telegram Premium subscription will be active after code activation.
payment_datenumberPoint in time (Unix timestamp) when the giveaway was paid.

More details on telegram's documentation.