View Source ExTDLib.Object.PublicChatTypeHasUsername (ExTDLib v0.0.4)
The chat is public, because it has an active username.
More details on telegram's documentation.
The chat is public, because it has an active username.
More details on telegram's documentation.