View Source ExTDLib.Object.StorePaymentPurposePremiumGiveaway (ExTDLib v0.0.4)

The user creating a Telegram Premium giveaway for subscribers of channel chats; requires can_post_messages rights in the channels.

NameTypeDescription
parameterspremiumGiveawayParametersGiveaway parameters.
currencystringISO 4217 currency code of the payment currency.
amountstringPaid amount, in the smallest units of the currency.

More details on telegram's documentation.