View Source ExTDLib.Object.StoryAreaType (ExTDLib v0.0.4)
This class is an abstract base class. Describes type of a clickable rectangle area on a story media.
More details on telegram's documentation.
This class is an abstract base class. Describes type of a clickable rectangle area on a story media.
More details on telegram's documentation.