View Source ExTDLib.Object.StoryOrigin (ExTDLib v0.0.4)
This class is an abstract base class. Contains information about the origin of a story that was reposted.
More details on telegram's documentation.
This class is an abstract base class. Contains information about the origin of a story that was reposted.
More details on telegram's documentation.