View Source ExTDLib.Object.SuggestedActionSubscribeToAnnualPremium (ExTDLib v0.0.4)
Suggests the user to subscribe to the Premium subscription with annual payments.
More details on telegram's documentation.
Suggests the user to subscribe to the Premium subscription with annual payments.
More details on telegram's documentation.