View Source ExTDLib.Object.TelegramPaymentPurposePremiumGiveaway (ExTDLib v0.0.4)

The user creating a Telegram Premium giveaway for subscribers of channel chats; requires can_post_messages rights in the channels.

NameTypeDescription
parameterspremiumGiveawayParametersGiveaway parameters.
currencystringISO 4217 currency code of the payment currency.
amountstringPaid amount, in the smallest units of the currency.
winner_countnumberNumber of users which will be able to activate the gift codes.
month_countnumberNumber of month the Telegram Premium subscription will be active for the users.

More details on telegram's documentation.