View Source ExTDLib.Object.TopChatCategory (ExTDLib v0.0.4)
This class is an abstract base class. Represents the categories of chats for which a list of frequently used chats can be retrieved.
More details on telegram's documentation.
This class is an abstract base class. Represents the categories of chats for which a list of frequently used chats can be retrieved.
More details on telegram's documentation.