View Source ExTDLib.Object.TopChatCategoryForwardChats (ExTDLib v0.0.4)
A category containing frequently used chats used to forward messages.
More details on telegram's documentation.
A category containing frequently used chats used to forward messages.
More details on telegram's documentation.