View Source ExTDLib.Object.UpdateAutosaveSettings (ExTDLib v0.0.4)

Autosave settings for some type of chats were updated.

NameTypeDescription
scopeAutosaveSettingsScopeType of chats for which autosave settings were updated.
settingsscopeAutosaveSettingsThe new autosave settings; may be null if the settings are reset to default.

More details on telegram's documentation.