View Source ExTDLib.Object.UpdateChatMember (ExTDLib v0.0.4)

User rights changed in a chat; for bots only.

NameTypeDescription
chat_idstringChat identifier.
actor_user_idstringIdentifier of the user, changing the rights.
datenumberPoint in time (Unix timestamp) when the user rights were changed.
invite_linkchatInviteLinkIf user has joined the chat using an invite link, the invite link; may be null.
via_chat_folder_invite_linkboolTrue, if the user has joined the chat using an invite link for a chat folder.
old_chat_memberchatMemberPrevious chat member.
new_chat_memberchatMemberNew chat member.

More details on telegram's documentation.