View Source ExTDLib.Object.UpdateSpeechRecognitionTrial (ExTDLib v0.0.4)

The parameters of speech recognition without Telegram Premium subscription has changed.

NameTypeDescription
max_media_durationnumberThe maximum allowed duration of media for speech recognition without Telegram Premium subscription.
weekly_countnumberThe total number of allowed speech recognitions per week; 0 if none.
left_countnumberNumber of left speech recognition attempts this week.
next_reset_datenumberPoint in time (Unix timestamp) when the weekly number of tries will reset; 0 if unknown.

More details on telegram's documentation.