View Source ExTDLib.Object.UpdateSupergroup (ExTDLib v0.0.4)

Some data of a supergroup or a channel has changed. This update is guaranteed to come before the supergroup identifier is returned to the application.

NameTypeDescription
supergroupsupergroupNew data about the supergroup.

More details on telegram's documentation.