View Source ExTDLib.Method.JoinGroupCall (ExTDLib v0.0.4)
Joins an active group call. Returns join response payload for tgcalls. Returns object_ptr<Text>.
| Name | Type | Description |
|---|---|---|
| group_call_id | number | Group call identifier. |
| participant_id | MessageSender | Identifier of a group call participant, which will be used to join the call; pass null to join as self; video chats only. |
| audio_source_id | number | Caller audio channel synchronization source identifier; received from tgcalls. |
| payload | string | Group call join payload; received from tgcalls. |
| is_muted | bool | Pass true to join the call with muted microphone. |
| is_my_video_enabled | bool | Pass true if the user's video is enabled. |
| invite_hash | string | If non-empty, invite hash to be used to join the group call without being muted by administrators. |
More details on telegram's documentation.