View Source ExTDLib.Method.ShareUserWithBot (ExTDLib v0.0.4)
Shares a user after pressing a keyboardButtonTypeRequestUser button with the bot. Returns object_ptr<Ok>.
| Name | Type | Description |
|---|---|---|
| chat_id | string | Identifier of the chat with the bot. |
| message_id | string | Identifier of the message with the button. |
| button_id | number | Identifier of the button. |
| shared_user_id | string | Identifier of the shared user. |
| only_check | bool | Pass true to check that the user can be shared by the button instead of actually sharing them. |
More details on telegram's documentation.