View Source ExTDLib.Object.ChatMemberStatusRestricted (ExTDLib v0.0.4)
The user is under certain restrictions in the chat. Not supported in basic groups and channels.
| Name | Type | Description |
|---|---|---|
| is_member | bool | True, if the user is a member of the chat. |
| restricted_until_date | number | Point in time (Unix timestamp) when restrictions will be lifted from the user; 0 if never. If the user is restricted for more than 366 days or for less than 30 seconds from the current time, the user is considered to be restricted forever. |
| permissions | chatPermissions | User permissions in the chat. |
More details on telegram's documentation.