View Source ExTDLib.Object.EmojiCategory (ExTDLib v0.0.4)
Contains a list of similar emoji to search for in getStickers and searchStickers.
| Name | Type | Description |
|---|---|---|
| name | string | Name of the category. |
| icon | sticker | Custom emoji sticker, which represents icon of the category. |
| emojis | string | List of emojis in the category. |
More details on telegram's documentation.