View Source ExTDLib.Object.LoginUrlInfoRequestConfirmation (ExTDLib v0.0.4)
An authorization confirmation dialog needs to be shown to the user.
| Name | Type | Description |
|---|---|---|
| url | string | An HTTP URL to be opened. |
| domain | string | A domain of the URL. |
| bot_user_id | string | User identifier of a bot linked with the website. |
| request_write_access | bool | True, if the user must be asked for the permission to the bot to send them messages. |
More details on telegram's documentation.