View Source ExTDLib.Object.MessageSponsorTypePublicChannel (ExTDLib v0.0.4)
The sponsor is a public channel chat.
| Name | Type | Description |
|---|---|---|
| chat_id | string | Sponsor chat identifier. |
| link | InternalLinkType | An internal link to be opened when the sponsored message is clicked; may be null if the sponsor chat needs to be opened instead. |
More details on telegram's documentation.