View Source ExTDLib.Object.PassportSuitableElement (ExTDLib v0.0.4)
Contains information about a Telegram Passport element that was requested by a service.
| Name | Type | Description |
|---|---|---|
| type | PassportElementType | Type of the element. |
| is_selfie_required | bool | True, if a selfie is required with the identity document. |
| is_translation_required | bool | True, if a certified English translation is required with the document. |
| is_native_name_required | bool | True, if personal details must include the user's name in the language of their country of residence. |
More details on telegram's documentation.