View Source ExTDLib.Object.PremiumGiveawayParticipantStatusAdministrator (ExTDLib v0.0.4)
The user can't participate in the giveaway, because they are an administrator in one of the chats that created the giveaway.
| Name | Type | Description |
|---|---|---|
| chat_id | string | Identifier of the chat administered by the user. |
More details on telegram's documentation.