View Source ExTDLib.Object.PremiumState (ExTDLib v0.0.4)
Contains state of Telegram Premium subscription and promotion videos for Premium features.
| Name | Type | Description |
|---|---|---|
| state | formattedText | Text description of the state of the current Premium subscription; may be empty if the current user has no Telegram Premium subscription. |
| payment_options | premiumStatePaymentOption | The list of available options for buying Telegram Premium. |
| animations | premiumFeaturePromotionAnimation | The list of available promotion animations for Premium features. |
More details on telegram's documentation.