View Source ExTDLib.Object.PrepaidPremiumGiveaway (ExTDLib v0.0.4)
Describes a prepaid Telegram Premium giveaway.
| Name | Type | Description |
|---|---|---|
| id | string | Unique identifier of the prepaid giveaway. |
| winner_count | number | Number of users which will receive Telegram Premium subscription gift codes. |
| month_count | number | Number of month the Telegram Premium subscription will be active after code activation. |
| payment_date | number | Point in time (Unix timestamp) when the giveaway was paid. |
More details on telegram's documentation.