View Source ExTDLib.Object.StorePaymentPurposePremiumGiveaway (ExTDLib v0.0.4)
The user creating a Telegram Premium giveaway for subscribers of channel chats; requires can_post_messages rights in the channels.
| Name | Type | Description |
|---|---|---|
| parameters | premiumGiveawayParameters | Giveaway parameters. |
| currency | string | ISO 4217 currency code of the payment currency. |
| amount | string | Paid amount, in the smallest units of the currency. |
More details on telegram's documentation.