View Source ExTDLib.Object.UpdateChatMember (ExTDLib v0.0.4)
User rights changed in a chat; for bots only.
| Name | Type | Description |
|---|---|---|
| chat_id | string | Chat identifier. |
| actor_user_id | string | Identifier of the user, changing the rights. |
| date | number | Point in time (Unix timestamp) when the user rights were changed. |
| invite_link | chatInviteLink | If user has joined the chat using an invite link, the invite link; may be null. |
| via_chat_folder_invite_link | bool | True, if the user has joined the chat using an invite link for a chat folder. |
| old_chat_member | chatMember | Previous chat member. |
| new_chat_member | chatMember | New chat member. |
More details on telegram's documentation.