View Source ExTDLib.Object.UpdateSpeechRecognitionTrial (ExTDLib v0.0.4)
The parameters of speech recognition without Telegram Premium subscription has changed.
| Name | Type | Description |
|---|---|---|
| max_media_duration | number | The maximum allowed duration of media for speech recognition without Telegram Premium subscription. |
| weekly_count | number | The total number of allowed speech recognitions per week; 0 if none. |
| left_count | number | Number of left speech recognition attempts this week. |
| next_reset_date | number | Point in time (Unix timestamp) when the weekly number of tries will reset; 0 if unknown. |
More details on telegram's documentation.